@@ -22,9 +22,6 @@
 #include <glibmm/exceptionhandler.h>
 
 
-#include <sigc++/hide.h>
-
-
 namespace Gnome
 {
 
@@ -42,8 +39,9 @@ static void libgnomeuimm_info_call(void* object, void* data)
 {
   try
   {
+    GtkWidget* cWidget = (GtkWidget*)object; //but we ignore this.
     InfoData* d = (InfoData*) data;
-    d->callback_(Glib::wrap((GtkWidget*)object));
+    d->callback_();
   }
   catch(...)
   {
@@ -139,7 +137,7 @@ const Gtk::Widget* Info::get_widget() const
 }
 
 
-void Info::set_accel(Gtk::Menu_Helpers::AccelKey key)
+void Info::set_accel(const Gtk::AccelKey& key)
 {
   GnomeUIInfo::accelerator_key = key.get_key();
   GnomeUIInfo::ac_mods = GdkModifierType(key.get_mod());
@@ -165,16 +163,6 @@ void Info::init_cb(Type type_, const Icon& icon_,
   info_->connect(*this);
 }
 
-void Info::init_cbw(Type type_, const Icon& icon_,
-          const Glib::ustring& label_, const CallbackWithWidget& callback_,
-          const Glib::ustring& hint_)
-{
-  InfoData* info_ = init_common(type_, icon_, label_, hint_);
-  info_->set_callback(callback_);
-
-  info_->connect(*this);
-}
-
 InfoData* Info::init_common(Type type_, const Icon& icon_,
                        const Glib::ustring& label_, const Glib::ustring& hint_)
 {
@@ -258,17 +246,6 @@ GnomeUIBuilderData Begin::build_data_ = { &libgnomeuimm_info_connect, 0, 0, 0, 0
 /*******************************************************************/
 
 
-
-/*******************************************************************/
-
-
-
-/*******************************************************************/
-
-
-
-
-
 } /* namespace Items */
 
 
@@ -370,7 +347,7 @@ void InfoData::connect(Info& info)
 
   info.set_data_(this); //Store this so that it can be reference-counted.
   
-  if(callback_.connected())
+  if(callback_) //This was if(callback_.connected()) for libsigc++ 1.2, and I'm not sure about the change. murrayc.
   {
     info.user_data = this;
     info.moreinfo = (void*)&libgnomeuimm_info_call;
@@ -404,16 +381,10 @@ void InfoData::connect(Info& info)
 
 void InfoData::set_callback(const Info::Callback& callback)
 {
-  if (callback.connected())
-    callback_ = SigC::hide<Gtk::Widget*>(callback);
+  //if(callback_) //TODO: This was if(callback_.connected()) for libsigc++ 1.2, and I'm not sure about the change. murrayc.
+    callback_ = callback;
 }
 
-void InfoData::set_callback(const Info::CallbackWithWidget& callback)
-{
-  callback_ = callback;
-}
-
-
 void InfoData::set_subtree(const Array<Info>& subtree)
 {
   subtree_ = subtree;
